==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Portada del sitio',
	'article' => 'Artículo',
	'articles' => 'Artículos',
	'articles_auteur' => 'Artículos de esta autora o autor',
	'articles_populaires' => 'Los artículos más populares',
	'articles_rubrique' => 'Artículos de esta sección',
	'aucun_article' => 'No hay ningún artículo en esta dirección ',
	'aucun_auteur' => 'No hay autor ni autora en esta dirección ',
	'aucun_site' => 'No hay ningún sitio en esta dirección',
	'aucune_breve' => 'No hay ninguna breve en esta dirección',
	'aucune_rubrique' => 'No hay ninguna sección en esta dirección',
	'auteur' => 'Autor o autora',
	'autres' => 'Otros',
	'autres_breves' => 'Otros breves',
	'autres_groupes_mots_clefs' => 'Otros grupos de palabras clave',
	'autres_sites' => 'Otros sitios',

	// B
	'bonjour' => 'Hola',

	// C
	'commenter_site' => 'Comentar este sitio',
	'contact' => 'Contacto',
	'copie_document_impossible' => 'Imposible copiar el documento',

	// D
	'date' => 'Fecha',
	'dernier_ajout' => 'Última actualización',
	'dernieres_breves' => 'Últimos breves',
	'derniers_articles' => 'Últimos artículos',
	'derniers_commentaires' => 'Últimos comentarios',
	'derniers_messages_forum' => 'Últimos mensajes publicados en los foros',

	// E
	'edition_mode_texte' => 'Edición en modo texto de',
	'en_reponse' => 'En respuesta a:',
	'en_resume' => 'En resumen',
	'envoyer_message' => 'Enviar un mensaje',
	'espace_prive' => 'Espacio privado',

	// F
	'formats_acceptes' => 'Formatos aceptados: @formats@.',

	// H
	'hierarchie_site' => 'Jerarquía del sitio',

	// J
	'jours' => 'días',

	// L
	'lien_connecter' => 'Conectarse',

	// M
	'meme_auteur' => 'Del mismo autor',
	'meme_rubrique' => 'En la misma sección',
	'memes_auteurs' => 'De los mismos autores',
	'message' => 'Mensaje',
	'messages_forum' => 'Mensajes',
	'messages_recents' => 'Los mensajes más recientes del foro',
	'mots_clef' => 'Palabra clave',
	'mots_clefs' => 'Palabras clave',
	'mots_clefs_meme_groupe' => 'Palabras claves en el mismo grupo',

	// N
	'navigation' => 'Navegación',
	'nom' => 'Nombre',
	'nouveautes' => 'Las novedades',
	'nouveautes_web' => 'Novedades en la web',
	'nouveaux_articles' => 'Nuevos artículos',
	'nouvelles_breves' => 'Nuevas breves',

	// P
	'page_precedente' => 'Página anterior',
	'page_suivante' => 'Página siguiente',
	'par_auteur' => 'por ',
	'participer_site' => 'Puedes participar en la vida de este sitio y proponer artículos inscribiéndote aqui. De inmediato recibirás un correo electrónico con tus claves de acceso al espacio privado del sitio.',
	'plan_site' => 'Mapa del sitio',
	'popularite' => 'Popularidad',
	'poster_message' => 'Publicar un mensaje',
	'proposer_site' => 'Proponga un sitio para añadir en esta sección:',

	// R
	'repondre_article' => 'Comentar este artículo',
	'repondre_breve' => 'Comentar esta breve',
	'resultats_recherche' => 'Resultados de la búsqueda',
	'retour_debut_forums' => 'Volver al inicio del foro',
	'rubrique' => 'Sección',
	'rubriques' => 'Secciones',

	// S
	'signatures_petition' => 'Firmas',
	'site_realise_avec_spip' => 'Sitio desarrollado con SPIP',
	'sites_web' => 'Sitios Web',
	'sous_rubriques' => 'Subsección',
	'spam' => 'Spam',
	'suite' => 'continuar',
	'sur_web' => 'Del web',
	'syndiquer_rubrique' => 'Sindicar esta sección',
	'syndiquer_site' => 'Sindicar el sitio completo',

	// T
	'texte_lettre_information' => 'Este es el boletín de información del sitio',
	'texte_lettre_information_2' => 'Este boletín reseña las novedades publicadas desde ',

	// V
	'ver_imprimer' => 'Versión para imprimir',
	'voir_en_ligne' => 'Ver en línea',
	'voir_squelette' => 'ver el esqueleto de esta página'
);

==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Portada del sitio',
	'article' => 'Artículo',
	'articles' => 'Artículos',
	'articles_auteur' => 'Artículos de esta autora o autor',
	'articles_populaires' => 'Los artículos más populares',
	'articles_rubrique' => 'Artículos de esta sección',
	'aucun_article' => 'No hay ningún artículo en esta dirección ',
	'aucun_auteur' => 'No hay autor ni autora en esta dirección ',
	'aucun_site' => 'No hay ningún sitio en esta dirección',
	'aucune_breve' => 'No hay ninguna breve en esta dirección',
	'aucune_rubrique' => 'No hay ninguna sección en esta dirección',
	'auteur' => 'Autor o autora',
	'autres' => 'Otros',
	'autres_breves' => 'Otros breves',
	'autres_groupes_mots_clefs' => 'Otros grupos de palabras clave',
	'autres_sites' => 'Otros sitios',

	// B
	'bonjour' => 'Hola',

	// C
	'commenter_site' => 'Comentar este sitio',
	'contact' => 'Contacto',
	'copie_document_impossible' => 'Imposible copiar el documento',

	// D
	'date' => 'Fecha',
	'dernier_ajout' => 'Última actualización',
	'dernieres_breves' => 'Últimos breves',
	'derniers_articles' => 'Últimos artículos',
	'derniers_commentaires' => 'Últimos comentarios',
	'derniers_messages_forum' => 'Últimos mensajes publicados en los foros',

	// E
	'edition_mode_texte' => 'Edición en modo texto de',
	'en_reponse' => 'En respuesta a:',
	'en_resume' => 'En resumen',
	'envoyer_message' => 'Enviar un mensaje',
	'espace_prive' => 'Espacio privado',

	// F
	'formats_acceptes' => 'Formatos aceptados: @formats@.',

	// H
	'hierarchie_site' => 'Jerarquía del sitio',

	// J
	'jours' => 'días',

	// L
	'lien_connecter' => 'Conectarse',

	// M
	'meme_auteur' => 'Del mismo autor',
	'meme_rubrique' => 'En la misma sección',
	'memes_auteurs' => 'De los mismos autores',
	'message' => 'Mensaje',
	'messages_forum' => 'Mensajes',
	'messages_recents' => 'Los mensajes más recientes del foro',
	'mots_clef' => 'Palabra clave',
	'mots_clefs' => 'Palabras clave',
	'mots_clefs_meme_groupe' => 'Palabras claves en el mismo grupo',

	// N
	'navigation' => 'Navegación',
	'nom' => 'Nombre',
	'nouveautes' => 'Las novedades',
	'nouveautes_web' => 'Novedades en la web',
	'nouveaux_articles' => 'Nuevos artículos',
	'nouvelles_breves' => 'Nuevas breves',

	// P
	'page_precedente' => 'Página anterior',
	'page_suivante' => 'Página siguiente',
	'par_auteur' => 'por ',
	'participer_site' => 'Puedes participar en la vida de este sitio y proponer artículos inscribiéndote aqui. De inmediato recibirás un correo electrónico con tus claves de acceso al espacio privado del sitio.',
	'plan_site' => 'Mapa del sitio',
	'popularite' => 'Popularidad',
	'poster_message' => 'Publicar un mensaje',
	'proposer_site' => 'Proponga un sitio para añadir en esta sección:',

	// R
	'repondre_article' => 'Comentar este artículo',
	'repondre_breve' => 'Comentar esta breve',
	'resultats_recherche' => 'Resultados de la búsqueda',
	'retour_debut_forums' => 'Volver al inicio del foro',
	'rss_abonnement' => 'Copie la siguiente URL en su agregador:',
	'rss_abonnement_titre' => 'Suscribirse',
	'rss_abonnement_titre_page' => 'Suscribirse a',
	'rss_explication' => 'Un feed RSS recoge información actualizada de un sitio. Proporciona el contenido de las entradas, comentarios o un extracto de los mismos, así como un enlace a las versiones completas y alguna otra información. Este feed está pensado para ser leído por un agregador RSS.',
	'rss_explication_titre' => '¿Qué es un feed RSS?',
	'rubrique' => 'Sección',
	'rubriques' => 'Secciones',

	// S
	'signatures_petition' => 'Firmas',
	'site_realise_avec_spip' => 'Sitio desarrollado con SPIP',
	'sites_web' => 'Sitios Web',
	'sous_rubriques' => 'Subsección',
	'spam' => 'Spam',
	'suite' => 'continuar',
	'sur_web' => 'Del web',
	'syndiquer_rubrique' => 'Sindicar esta sección',
	'syndiquer_site' => 'Sindicar el sitio completo',

	// T
	'texte_lettre_information' => 'Este es el boletín de información del sitio',
	'texte_lettre_information_2' => 'Este boletín reseña las novedades publicadas desde ',

	// V
	'ver_imprimer' => 'Versión para imprimir',
	'voir_en_ligne' => 'Ver en línea',
	'voir_squelette' => 'ver el esqueleto de esta página'
);
